<?php
/**
 * Plugin Name: DISC Personality Test
 *  * Plugin URI: https://tanar.ir/disc-personality-test
 * Description: افزونه رایگان تست دیسک برای وب سایت های وردپرسی - با افتخار ساخت ایران - امیرحسین فخاری از آکادمی انار
 * Version: 1.0
 * Author: Amirhosein Fakhari
 * Author URI: https://tanar.ir
 * License: GPL2
 * Tested up to: 6.7
 * Stable tag: 1.0
 * Plugin Name: DISC Personality Test
 * License: GPL2
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */
 
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

// اضافه کردن استایل و اسکریپت‌ها
function disc_test_enqueue_styles() {
    ?>
    <style>
        #disc-test {
            font-family: Iransans, Arial, sans-serif;
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
            background-color: #f4f4f9;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        #disc-test h3 {
            text-align: center;
            color: #333;
        }

        .question {
            margin-bottom: 20px;
        }

        .question label {
            font-weight: bold;
            color: #444;
        }

        .question input[type="radio"] {
            margin-right: 10px;
        }

        button[type="submit"] {
            width: 100%;
            padding: 10px;
            background-color: #0073e6;
            color: #fff;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
        }

        button[type="submit"]:hover {
            background-color: #005bb5;
        }

        .result {
            margin-top: 20px;
            padding: 15px;
            background-color: #e7f7e7;
            border: 1px solid #c6e7c6;
            border-radius: 5px;
            color: #2d6a2f;
            text-align: center;
        }

        .result h3 {
            margin-bottom: 10px;
        }

        .result p {
            font-size: 16px;
        }
    </style>

    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script>
        // داده‌های تست DISC برای نمودار
        function displayChart(data) {
            var ctx = document.getElementById('personalityChart').getContext('2d');
            var personalityChart = new Chart(ctx, {
                type: 'pie',
                data: {
                    labels: ['D', 'I', 'S', 'C'],
                    datasets: [{
                        label: 'Distribution of Personality Traits',
                        data: data, // داده‌ها برای درصد هر تایپ
                        backgroundColor: ['#FF5733', '#33C1FF', '#8E44AD', '#2ECC71'],
                        borderColor: ['#FF5733', '#33C1FF', '#8E44AD', '#2ECC71'],
                        borderWidth: 1
                    }]
                }
            });
        }
    </script>
    <?php
}
add_action('wp_head', 'disc_test_enqueue_styles');

// ایجاد شورتکد برای نمایش فرم تست DISC
function disc_test_shortcode() {
    ob_start();
    ?>
    <div id="disc-test">
        <form id="disc-test-form" method="POST">
            <h3>DISC Personality Test</h3>
            <p>لطفاً به سوالات زیر پاسخ دهید. برای هر سوال تنها یک پاسخ را انتخاب کنید.</p>

            <?php
            // اضافه کردن 20 سوال جدید
            $questions = [
                1 => "1. وقتی با مشکلی روبرو می‌شوم، اولین واکنشم این است که سریعاً یک راه‌حل برای آن پیدا کنم.",
                2 => "2. من دوست دارم در موقعیت‌های اجتماعی حضور داشته باشم و با دیگران تعامل کنم.",
                3 => "3. در شرایط فشار کاری، ترجیح می‌دهم که یک فرد پایدار و مهربان باشم تا درگیری ایجاد کنم.",
                4 => "4. وقتی که با پروژه‌ای مواجه می‌شوم، من اولاً به جزئیات توجه می‌کنم تا اینکه به تصویر بزرگ‌تر.",
                5 => "5. من معمولاً سریع و قاطعانه تصمیم می‌گیرم حتی اگر همه اطلاعات را نداشته باشم.",
                6 => "6. اگر فردی من را مورد انتقاد قرار دهد، معمولاً به آن واکنش مثبتی نشان می‌دهم و سعی می‌کنم خود را بهتر کنم.",
                7 => "7. برای من مهم است که در محیطی با ثبات و آرام کار کنم.",
                8 => "8. من تمایل دارم که همیشه از قوانین و استانداردها پیروی کنم، حتی اگر همه افراد دیگر به آن‌ها توجه نکنند.",
                9 => "9. من اغلب در موقعیت‌های رهبری حضور می‌یابم.",
                10 => "10. من احساس می‌کنم باید کارها را سریع انجام دهم، حتی اگر نیاز به دقت زیاد باشد.",
                11 => "11. من ترجیح می‌دهم به افراد انگیزه بدهم تا اینکه خودم مسئولیت انجام کارها را بر عهده بگیرم.",
                12 => "12. من در کارهای گروهی به شدت مشارکت می‌کنم.",
                13 => "13. من از برنامه‌ریزی و تنظیم زمان برای انجام کارها لذت می‌برم.",
                14 => "14. وقتی که تحت فشار قرار می‌گیرم، بیشتر به دنبال آرامش و ثبات هستم تا رسیدن به اهداف.",
                15 => "15. من نمی‌توانم به راحتی از تغییرات یا روال‌های جدید استقبال کنم.",
                16 => "16. من تمایل دارم که به دیگران اولویت دهم و نیازهایشان را درک کنم.",
                17 => "17. من به شدت به نتایج نهایی توجه می‌کنم، حتی اگر جزئیات نادیده گرفته شوند.",
                18 => "18. من معمولاً در موقعیت‌های اجتماعی می‌درخشم و دیگران را تحت تأثیر قرار می‌دهم.",
                19 => "19. من نسبت به مسائل احساسی بسیار حساس و دلسوز هستم.",
                20 => "20. من تمایل دارم که در کارها و پروژه‌ها به رویکرد سیستماتیک و دقیق بچسبم."
            ];

            // ایجاد سوالات به صورت داینامیک
            foreach ($questions as $index => $question) {
                ?>
                <div class="question">
                    <label for="q<?php echo $index; ?>"><?php echo $question; ?></label><br>
                    <input type="radio" name="q<?php echo $index; ?>" value="D"> کاملاً موافقم<br>
                    <input type="radio" name="q<?php echo $index; ?>" value="I"> موافقم<br>
                    <input type="radio" name="q<?php echo $index; ?>" value="S"> مخالفم<br>
                    <input type="radio" name="q<?php echo $index; ?>" value="C"> کاملاً مخالفم<br>
                </div>
                <?php
            }
            ?>
            <button type="submit" name="submit_disc_test">ارسال پاسخ‌ها</button>
        </form>

        <?php
        if (isset($_POST['submit_disc_test'])) {
            $result = process_disc_test();
            echo "<div class='result'><h3>نتیجه آزمون شما:</h3><p>" . $result['text'] . "</p><p>شخصیت شما: " . $result['type'] . "</p>";
            echo "<canvas id='personalityChart' width='400' height='400'></canvas>";
            echo "<script>displayChart([" . implode(", ", $result['chart_data']) . "]);</script></div>";
        }
        ?>
    </div>
    <?php
    return ob_get_clean();
}
add_shortcode('disc_test', 'disc_test_shortcode');

// پردازش پاسخ‌ها و محاسبه نتیجه
function process_disc_test() {
    $score = ['D' => 0, 'I' => 0, 'S' => 0, 'C' => 0];
    $questions = 20; // تعداد سوالات

    for ($i = 1; $i <= $questions; $i++) {
        if (isset($_POST["q$i"])) {
            $score[$_POST["q$i"]]++;
        }
    }

    // پیدا کردن بیشترین امتیاز
    arsort($score);
    reset($score);
    $dominant_trait = key($score);

    // توضیح شخصیت
    $descriptions = [
        'D' => "شخصیت شما: رهبری، قوی و تصمیم‌گیرنده. شما معمولاً در موقعیت‌های چالش‌برانگیز تصمیمات قاطعانه می‌گیرید. شخصیت شما در موقعیت‌های دشوار آرامش خود را از دست نمی‌دهد و با سرعت و دقت به سمت حل مسئله می‌رود. شما می‌خواهید کنترل همه چیز را در دست داشته باشید و اغلب در موقعیت‌های رهبری قرار می‌گیرید.",
        'I' => "شخصیت شما: اجتماعی، انرژی‌زا و مثبت. شما تمایل دارید روابط نزدیک و دوستانه برقرار کنید. شما خوش‌بین و انگیزه‌دهنده هستید و از تعامل با دیگران لذت می‌برید. شخصیت شما اغلب به‌عنوان منبع انرژی و الهام برای دیگران شناخته می‌شود. شما فردی هستید که در محیط‌های اجتماعی می‌درخشید.",
        'S' => "شخصیت شما: آرام، حامی و پایدار. شما اغلب در جستجوی صلح و آرامش هستید و توانایی گوش دادن و کمک به دیگران را دارید. شما فردی هستید که به‌طور دائم در تلاش برای حفظ تعادل در زندگی خود و دیگران هستید. شخصیت شما بر اساس حمایت و محبت است و ترجیح می‌دهید به‌جای تغییرات زیاد، به ثبات و آرامش پایبند باشید.",
        'C' => "شخصیت شما: دقیق، منطقی و تحلیلی. شما به جزئیات توجه زیادی دارید و از روش‌های دقیق برای حل مسائل استفاده می‌کنید. شما فردی هستید که در کارهای خود بسیار سیستماتیک و دقیق است. شما ترجیح می‌دهید همه‌چیز را طبق استانداردهای بالا انجام دهید و به‌دنبال بهبود مستمر فرآیندها هستید."
    ];

    $chart_data = [
        'D' => $score['D'],
        'I' => $score['I'],
        'S' => $score['S'],
        'C' => $score['C']
    ];

    return ['text' => $descriptions[$dominant_trait], 'type' => $dominant_trait, 'chart_data' => $chart_data];
}
?>
